@@ -219,6 +219,31 @@ arma::mat Robust_estimate (arma::mat X, arma::mat phi, arma::mat B, float CT)
 }
 
 
+// [[Rcpp::export]]
+arma::mat mu_robust_F_noCV( arma::mat X, arma::mat phi, arma::mat tau)
+{
+  using namespace arma;
+  int i, P, K;
+  P=X.n_rows;
+  K=phi.n_cols;
+  float tau_select;
+  mat F_H_0; F_H_0.ones(K);
+  mat Xi;
+  mat mu_hat; mu_hat.zeros(K,P);
+
+  for(i=0;i<P;i++){
+    Rcpp::checkUserInterrupt();
+    Xi=X.row(i);
+    F_H_0=solve(phi,trans(Xi));
+    tau_select  = tau(i);
+    mu_hat.col(i)=Huber_descent(Xi, phi, F_H_0,tau_select);
+  }
+  return mu_hat;
+
+}
+
+
+
 // [[Rcpp::export]]
 arma::mat mu_robust_F( arma::mat X, arma::mat phi)
 {
@@ -265,7 +290,7 @@ arma::mat Cov_Huber( arma::mat X, arma::mat phi)
     for(j=0;j<=i;j++){
       Xi=X.row(i); Xj=X.row(j);
       F_H_0=solve(phi,trans(Xi%Xj));
-      Tau= Robust_CV (trans(Xi%Xj), phi);
+      Tau = Robust_CV (trans(Xi%Xj), phi);
       Sigma_hat(i,j)=arma::conv_to<double>::from(Huber_descent (Xi%Xj,phi, F_H_0, Tau));
       Sigma_hat(j,i)=Sigma_hat(i,j);
     }
@@ -277,6 +302,73 @@ arma::mat Cov_Huber( arma::mat X, arma::mat phi)
 }
 
 
+//Output: Estimated tuning parameter for covriance matrix
+// [[Rcpp::export]]
+arma::mat Cov_Huber_tune( arma::mat X, float tau)
+{
+  using namespace arma;
+  int i, j, P=X.n_rows, N=X.n_cols;
+
+  //Tuning parameter
+  float tautemp;
+
+  //Define the matrices
+  mat Xi, Xj;
+  mat CT; CT.zeros(P,P);
+  mat Z; Z.ones(N);
+  mat sd;
+
+  // Entry-wise Huber method
+  for(i=0;i<P;i++){
+    Rcpp::checkUserInterrupt();
+    for(j=0;j<=i;j++){
+      Xi=X.row(i); Xj=X.row(j);
+      Z = Xi%Xj;
+      sd = arma::stddev(Z,1,1);
+      tautemp  = N/log(static_cast<double>((P^2)*N));
+      CT(i,j) = tau*(sd(0,0)*sqrt(static_cast<double>(tautemp)));
+      //cout << CT(i,j);
+      CT(j,i)=CT(i,j);
+    }
+  }
+
+  return CT;
+
+}
+
+//Output: Estimated cov matrix Sigma_hat
+// [[Rcpp::export]]
+arma::mat Cov_Huber_noCV( arma::mat X, arma::mat phi, arma::mat tau)
+{
+  using namespace arma;
+  int i, j, P=X.n_rows;
+
+
+  //Tuning parameter
+  float tau_select;
+
+  //Define the matrices
+  mat Xi, Xj;
+  mat Sigma_hat; Sigma_hat.zeros(P,P);
+  mat F_H_0; F_H_0.ones(1);
+
+  //Entry-wise Huber method
+  for(i=0;i<P;i++){
+    Rcpp::checkUserInterrupt();
+    for(j=0;j<=i;j++){
+      Xi=X.row(i); Xj=X.row(j);
+      F_H_0=solve(phi,trans(Xi%Xj));
+      tau_select = tau(i,j);
+      Sigma_hat(i,j)=arma::conv_to<double>::from(Huber_descent (Xi%Xj,phi, F_H_0, tau_select));
+      Sigma_hat(j,i)=Sigma_hat(i,j);
+    }
+  }
+
+
+  return Sigma_hat;
+
+}
+
 
 
 //Find factors
